<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author DoK <kamberd@yahoo.com>
 * @author Dotan Kamber <kamberd@yahoo.com>
 * @author Moshe Kaplan <mokplan@gmail.com>
 * @author Yaron Yogev <yaronyogev@gmail.com>
 * @author Yaron Shahrabani <sh.yaron@gmail.com>
 * @author sagi <sagiyosef@gmail.com>
 */
$lang['menu']                  = 'הגדרות תצורה';
$lang['error']                 = 'ההגדרות לא עודכנו בגלל ערך לא תקף, נא לעיין בשינויים ולשלוח שנית.
                       <br />הערכים שאינם נכונים יסומנו בגבול אדום.';
$lang['updated']               = 'ההגדרות עודכנו בהצלחה.';
$lang['nochoice']              = '(אין אפשרויות זמינות נוספות)';
$lang['locked']                = 'קובץ ההגדרות אינו בר עידכון, אם הדבר אינו מכוון, <br />
                       יש לודא כי קובץ ההגדרות המקומי וההרשאות נכונים.';
$lang['_configuration_manager'] = 'מנהל תצורה';
$lang['_header_dokuwiki']      = 'הגדרות DokuWiki';
$lang['_header_plugin']        = 'הגדרות תוסף';
$lang['_header_template']      = 'הגדרות תבנית';
$lang['_header_undefined']     = 'הגדרות שונות';
$lang['_basic']                = 'הגדרות בסיסיות';
$lang['_display']              = 'הגדרות תצוגה';
$lang['_authentication']       = 'הגדרות הזדהות';
$lang['_anti_spam']            = 'הגדרות נגד דואר זבל';
$lang['_editing']              = 'הגדרות עריכה';
$lang['_links']                = 'הגדרות קישורים';
$lang['_media']                = 'הגדרות מדיה';
$lang['_advanced']             = 'הגדרות מתקדמות';
$lang['_network']              = 'הגדרות רשת';
$lang['_msg_setting_undefined'] = 'אין מידע-על להגדרה.';
$lang['_msg_setting_no_class'] = 'אין קבוצה להגדרה.';
$lang['_msg_setting_no_default'] = 'אין ערך ברירת מחדל.';
$lang['title']                 = 'כותרת הויקי';
$lang['start']                 = 'שם דף הפתיחה';
$lang['lang']                  = 'שפה';
$lang['template']              = 'תבנית';
$lang['savedir']               = 'ספריה לשמירת מידע';
$lang['basedir']               = 'ספרית בסיס';
$lang['baseurl']               = 'כתובת URL בסיסית';
$lang['dmode']                 = 'מצב יצירת ספריה';
$lang['fmode']                 = 'מצב יצירת קובץ';
$lang['allowdebug']            = 'אפשר דיבוג <b>יש לבטל אם אין צורך!</b>';
$lang['recent']                = 'שינויים אחרונים';
$lang['recent_days']           = 'כמה שינויים אחרונים לשמור (ימים)';
$lang['breadcrumbs']           = 'מספר עקבות להיסטוריה';
$lang['youarehere']            = 'עקבות היררכיות להיסטוריה';
$lang['fullpath']              = 'הצגת נתיב מלא לדפים בתחתית';
$lang['typography']            = 'שימוש בחלופות טיפוגרפיות';
$lang['dformat']               = 'תסדיר תאריך (נא לפנות לפונקציה <a href="http://php.net/strftime">strftime</a> של PHP)';
$lang['signature']             = 'חתימה';
$lang['toptoclevel']           = 'רמה עליונה בתוכן הענינים';
$lang['maxtoclevel']           = 'רמה מירבית בתוכן הענינים';
$lang['maxseclevel']           = 'רמה מירבית בעריכת קטעים';
$lang['camelcase']             = 'השתמש בראשיות גדולות לקישורים';
$lang['deaccent']              = 'נקה שמות דפים';
$lang['useheading']            = 'השתמש בכותרת הראשונה לשם הדף';
$lang['sneaky_index']          = 'כברירת מחדל, דוקוויקי יציג את כל מרחבי השמות בתצוגת תוכן הענינים. בחירה באפשרות זאת תסתיר את אלו שבהם למשתמש אין הרשאות קריאה. התוצאה עלולה להיות הסתרת תת מרחבי שמות אליהם יש למשתמש גישה. באופן זה תוכן הענינים עלול להפוך לחסר תועלת עם הגדרות ACL מסוימות';
$lang['hidepages']             = 'הסתר דפים תואמים (ביטויים רגולריים)';
$lang['useacl']                = 'השתמש ברשימות בקרת גישה';
$lang['autopasswd']            = 'צור סיסמאות באופן אוטומטי';
$lang['authtype']              = 'מנוע הזדהות';
$lang['passcrypt']             = 'שיטת הצפנת סיסמאות';
$lang['defaultgroup']          = 'קבוצת ברירת המחדל';
$lang['superuser']             = 'משתמש-על';
$lang['manager']               = 'מנהל - קבוצה, משתמש או רשימה מופרדת בפסיקים משתמש1, @קבוצה1, משתמש2 עם גישה לפעולות ניהול מסוימות.';
$lang['profileconfirm']        = 'אשר שינוי פרופילים עם סיסמה';
$lang['disableactions']        = 'בטל פעולות DokuWiki';
$lang['disableactions_check']  = 'בדיקה';
$lang['disableactions_subscription'] = 'הרשמה/הסרה מרשימה';
$lang['disableactions_wikicode'] = 'הצגת המקור/יצוא גולמי';
$lang['disableactions_other']  = 'פעולות אחרות (מופרדות בפסיק)';
$lang['auth_security_timeout'] = 'מגבלת אבטח פסק הזמן להזדהות (שניות)';
$lang['usewordblock']          = 'חסימת דואר זבל לפי רשימת מילים';
$lang['relnofollow']           = 'השתמש ב- rel="nofollow" לקישורים חיצוניים';
$lang['indexdelay']            = 'השהיה בטרם הכנסה לאינדקס (שניות)';
$lang['mailguard']             = 'הגן על כתובות דוא"ל';
$lang['iexssprotect']          = 'בדוק את הדפים המועלים לחשד ל-JavaScript או קוד HTML זדוני';
$lang['usedraft']              = 'שמור טיוטות באופן אוטומטי בעת עריכה';
$lang['htmlok']                = 'אישור שיבוץ HTML';
$lang['phpok']                 = 'אישור שיבוץ PHP';
$lang['locktime']              = 'גיל מירבי לקבצי נעילה (שניות)';
$lang['cachetime']             = 'גיל מירבי לזכרון מטמון (שניות)';
$lang['target____wiki']        = 'חלון יעד לקישורים פנימיים';
$lang['target____interwiki']   = 'חלון יעד לקישורים בין מערכות ויקי';
$lang['target____extern']      = 'חלון יעד לקישורים חיצוניים';
$lang['target____media']       = 'חלון יעד לקישור למדיה';
$lang['target____windows']     = 'חלון יעד לתיקיות משותפות';
$lang['refcheck']              = 'בדוק שיוך מדיה';
$lang['gdlib']                 = 'גרסת ספרית ה-GD';
$lang['im_convert']            = 'נתיב לכלי ה-convert של ImageMagick';
$lang['jpg_quality']           = 'איכות הדחיסה של JPG (0-100)';
$lang['fetchsize']             = 'גודל הקובץ המירבי (bytes) ש-fetch.php יכול להוריד מבחוץ';
$lang['subscribers']           = 'התר תמיכה ברישום לדפים';
$lang['notify']                = 'שלח התראות על שינויים לכתובת דוא"ל זו';
$lang['registernotify']        = 'שלח מידע על משתמשים רשומים חדשים לכתובת דוא"ל זו';
$lang['mailfrom']              = 'כתובת הדוא"ל לשימוש בדברי דוא"ל אוטומטיים';
$lang['sitemap']               = 'צור מפת אתר של Google (ימים)';
$lang['rss_type']              = 'סוג פלט XML';
$lang['rss_linkto']            = 'פלט ה-XML מקשר אל';
$lang['rss_content']           = 'מה להציג בפרטי פלט ה-XML';
$lang['rss_update']            = 'פלט ה-XML מתעדכן כל (שניות)';
$lang['rss_show_summary']      = 'פלט ה-XML מציג תקציר בכותרת';
$lang['updatecheck']           = 'בדיקת עידכוני אבטחה והתראות? על DokuWiki להתקשר אל update.dokuwiki.org לצורך כך.';
$lang['userewrite']            = 'השתמש בכתובות URL יפות';
$lang['useslash']              = 'השתמש בלוכסן להגדרת מרחבי שמות בכתובות';
$lang['sepchar']               = 'מפריד בין מילות שם-דף';
$lang['canonical']             = 'השתמש בכתובות URL מלאות';
$lang['autoplural']            = 'בדוק לצורת רבים בקישורים';
$lang['compression']           = 'אופן דחיסת קבצים ב-attic';
$lang['gzip_output']           = 'השתמש בקידוד תוכן של gzip עבור xhtml';
$lang['compress']              = 'פלט קומפקטי של CSS ו-javascript';
$lang['send404']               = 'שלח "HTTP 404/Page Not Found" עבור דפים שאינם קיימים';
$lang['broken_iua']            = 'האם הפעולה ignore_user_abort תקולה במערכת שלך? הדבר עלול להביא לתוכן חיפוש שאינו תקין. IIS+PHP/CGI ידוע כתקול. ראה את <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">באג 852</a> למידע נוסף';
$lang['xsendfile']             = 'להשתמש בכותר X-Sendfile כדי לאפשר לשרת לספק קבצים סטטיים? על השרת שלך לתמוך באפשרות זאת.';
$lang['renderer_xhtml']        = 'מחולל לשימוש עבור פלט הויקי העיקרי (xhtml)';
$lang['renderer__core']        = '%s (ליבת דוקוויקי)';
$lang['renderer__plugin']      = '%s (הרחבות)';
$lang['proxy____host']         = 'שם השרת המתווך';
$lang['proxy____port']         = 'שער השרת המתווך';
$lang['proxy____user']         = 'שם המשתמש בשרת המתווך';
$lang['proxy____pass']         = 'סיסמת ההשרת המתווך';
$lang['proxy____ssl']          = 'השתמש ב-ssl כדי להתחבר לשרת המתווך';
$lang['safemodehack']          = 'אפשר שימוש בפתרון ל-safemode';
$lang['ftp____host']           = 'שרת FTP עבור פתרון ה-safemode';
$lang['ftp____port']           = 'שער ה-FTP עבור פתרון ה-safemode';
$lang['ftp____user']           = 'שם המשתמש ב-FTPעבור פתרון ה-safemode';
$lang['ftp____pass']           = 'סיסמת ה-FTP לפתרון ה-safemode';
$lang['ftp____root']           = 'ספרית השורש ב-FTP עבור פתרון ה-safemode';
$lang['typography_o_0']        = 'ללא';
$lang['typography_o_1']        = 'רק גרשיים כפולים';
$lang['typography_o_2']        = 'כל הגרשים (עלול שלא לעבוד לעיתים)';
$lang['userewrite_o_0']        = 'ללא';
$lang['userewrite_o_1']        = '.htaccess';
$lang['userewrite_o_2']        = 'פנימי של DokuWiki';
$lang['deaccent_o_0']          = 'כבוי';
$lang['deaccent_o_1']          = 'הסר ניבים';
$lang['deaccent_o_2']          = 'הסב ללטינית';
$lang['gdlib_o_0']             = 'ספרית ה-GD אינה זמינה';
$lang['gdlib_o_1']             = 'גרסה 1.x';
$lang['gdlib_o_2']             = 'זיהוי אוטומטי';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'תקציר';
$lang['rss_content_o_diff']    = 'הבדלים מאוחדים';
$lang['rss_content_o_htmldiff'] = 'טבלת HTML של ההבדלים';
$lang['rss_content_o_html']    = 'מלוא תוכן דף HTML';
$lang['rss_linkto_o_diff']     = 'תצוגת הבדלים';
$lang['rss_linkto_o_page']     = 'הדף שהשתנה';
$lang['rss_linkto_o_rev']      = 'גרסאות קודמות';
$lang['rss_linkto_o_current']  = 'הדף הנוכחי';
$lang['compression_o_0']       = 'ללא';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'אל תשתמש';
$lang['xsendfile_o_1']         = 'כותר lighttpd קנייני (לפני גרסה 1.5)';
$lang['xsendfile_o_2']         = 'כותר X-Sendfile רגיל';
$lang['xsendfile_o_3']         = 'כותר Nginx X-Accel-Redirect קנייני';
$lang['useheading_o_navigation'] = 'ניווט בלבד';
$lang['useheading_o_1']        = 'תמיד';
